@@ -4,9 +4,9 @@ import sys
 import threading
 
 sys.path.insert(0, '../frontiersman')
-from gameboard.Board import *
-from client.Gui import *
-from client.Player import *
+from frontiersman.gameboard.Board import *
+from frontiersman.client.Gui import *
+from frontiersman.client.Player import *
 
 sep = '\n'
 enemy_list = []
@@ -39,10 +39,6 @@ class client:
     def board_thread(self, board):
         self.client_instance.run(board)
 
-    @staticmethod
-    def main(address='127.0.0.1', port=1233, name='Zander', num_players=2):
-        client(address, int(port), name, int(num_players))
-
     def __init__(self, host_ip, port_ip, player_name='John', num_players=2):
         board_input = queue.Queue()
         board = Board()
@@ -284,25 +280,41 @@ class client:
         # roadMap.printAllRoads()
         self.client_instance.quit()
         ClientSocket.close()
+def main():
+    address='127.0.0.1'
+    port=1233
+    name='Zander'
+    num_players=2
+    print(sys.argv)
+    if(len(sys.argv)==5):
+        address=sys.argv[1]
+        port=int(sys.argv[2])
+        name=sys.argv[3]
+        num_players=int(sys.argv[4])
+    client(address, int(port), name, int(num_players))
+
+
+# if __name__ == "__main__":
+#     host = '127.0.0.1'
+#     port = 1233
+#     xy = ''
+#     Name = "Name"
+#     players = 2
+#     host = sys.argv[1]
+#     try:
+#         port = int(sys.argv[2])
+#     except(ValueError):
+#         print("port must be an int")
+#     Name = sys.argv[3]
+#     if (len(sys.argv) == 5):
+#         try:
+#             players = int(sys.argv[4])
+#         except(ValueError):
+#             print("number of players must be an int")
+#         test = client(host, port, Name, players)
+#     else:
+#         test = client(host, port, Name)
+
+
 
 
-if __name__ == "__main__":
-    host = '127.0.0.1'
-    port = 1233
-    xy = ''
-    Name = "Name"
-    players = 2
-    host = sys.argv[1]
-    try:
-        port = int(sys.argv[2])
-    except(ValueError):
-        print("port must be an int")
-    Name = sys.argv[3]
-    if (len(sys.argv) == 5):
-        try:
-            players = int(sys.argv[4])
-        except(ValueError):
-            print("number of players must be an int")
-        test = client(host, port, Name, players)
-    else:
-        test = client(host, port, Name)
