@@ -1,6 +1,6 @@
 import pygame
 import pygame_gui as pg_g
-from client.GuiConstants import CARD_SIZE, SPACING
+from frontiersman.client.GuiConstants import CARD_SIZE, SPACING
 
 CARDS = ['Brick', 'Ore', 'Sheep', 'Wheat', 'Wood']
 
